emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/org a20a3ad 08/14: Plug citations into `org-open-at-poi


From: ELPA Syncer
Subject: [elpa] externals/org a20a3ad 08/14: Plug citations into `org-open-at-point'
Date: Fri, 9 Jul 2021 02:57:18 -0400 (EDT)

branch: externals/org
commit a20a3ad5f11f85af73c15ac153dd2e945a79df93
Author: Nicolas Goaziou <mail@nicolasgoaziou.fr>
Commit: Nicolas Goaziou <mail@nicolasgoaziou.fr>

    Plug citations into `org-open-at-point'
    
    * lisp/org.el (org-open-at-point): Follow citations and citation
    references.
---
 lisp/org.el | 10 ++++++----
 1 file changed, 6 insertions(+), 4 deletions(-)

diff --git a/lisp/org.el b/lisp/org.el
index 297e882..9548155 100644
--- a/lisp/org.el
+++ b/lisp/org.el
@@ -8955,9 +8955,10 @@ a link."
            ;; closest one.
            (org-element-lineage
             (org-element-context)
-            '(clock comment comment-block footnote-definition
-                    footnote-reference headline inline-src-block inlinetask
-                    keyword link node-property planning src-block timestamp)
+            '(citation citation-reference clock comment comment-block
+                        footnote-definition footnote-reference headline
+                        inline-src-block inlinetask keyword link node-property
+                        planning src-block timestamp)
             t))
           (type (org-element-type context))
           (value (org-element-property :value context)))
@@ -8968,7 +8969,7 @@ a link."
        ((memq type '(comment comment-block node-property keyword))
        (call-interactively #'org-open-at-point-global))
        ;; On a headline or an inlinetask, but not on a timestamp,
        ;; a link, a footnote reference.
        ((memq type '(headline inlinetask))
        (org-match-line org-complex-heading-regexp)
        (let ((tags-beg (match-beginning 5))
@@ -9031,6 +9032,7 @@ a link."
        ((eq type 'inline-src-block) (org-babel-open-src-block-result))
        ((eq type 'timestamp) (org-follow-timestamp-link))
        ((eq type 'link) (org-link-open context arg))
+       ((memq type '(citation citation-reference)) (org-cite-follow context 
arg))
        (t (user-error "No link found")))))
   (run-hook-with-args 'org-follow-link-hook))
@@ -8968,7 +8969,7 @@ a link."
        (call-interactively #'org-open-at-point-global))
        ;; On a headline or an inlinetask, but not on a timestamp,
-       ;; a link, a footnote reference.
+       ;; a link, a footnote reference or a citation.
        ((memq type '(headline inlinetask))
        (org-match-line org-complex-heading-regexp)
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]